Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(793)

Unified Diff: third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h
diff --git a/third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h b/third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h
index 5029ef4eec19b10b8c9ee79370c3d83c2c707c28..22a5f1696ff4d83f055af746c7a5fdfee9ecb4a8 100644
--- a/third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h
+++ b/third_party/WebKit/Source/core/paint/PaintInvalidationCapableScrollableArea.h
@@ -32,9 +32,8 @@ class CORE_EXPORT PaintInvalidationCapableScrollableArea
void invalidatePaintOfScrollControlsIfNeeded(const PaintInvalidationState&);
void invalidatePaintOfScrollControlsIfNeeded(const PaintInvalidatorContext&);
- // Should be called when the previous paint invalidation rects are no longer
- // valid.
- void clearPreviousPaintInvalidationRects();
+ // Should be called when the previous visual rects are no longer valid.
+ void clearPreviousVisualRects();
virtual IntRect scrollCornerAndResizerRect() const {
return scrollCornerRect();
@@ -50,9 +49,9 @@ class CORE_EXPORT PaintInvalidationCapableScrollableArea
bool m_horizontalScrollbarPreviouslyWasOverlay;
bool m_verticalScrollbarPreviouslyWasOverlay;
- LayoutRect m_horizontalScrollbarPreviousPaintInvalidationRect;
- LayoutRect m_verticalScrollbarPreviousPaintInvalidationRect;
- LayoutRect m_scrollCornerAndResizerPreviousPaintInvalidationRect;
+ LayoutRect m_horizontalScrollbarPreviousVisualRect;
+ LayoutRect m_verticalScrollbarPreviousVisualRect;
+ LayoutRect m_scrollCornerAndResizerPreviousVisualRect;
};
} // namespace blink

Powered by Google App Engine
This is Rietveld 408576698